==> aroundme_0_5_0.tar.tgz: aroundme_0_5_0/aroundme/language/1/barnraiser_01/node_register_user.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------


require_once($languagePath . 'node_common.lang.php');
/*
* All language vars should be ordered TYPE, A-Z for convenience
* Tom Calthrop - 20th April 2004 (tom@barnraiser.org)
*/


//SECTIONS
$lang['section_invite'] = 						"you've been invited";
$lang['section_registration'] = 				"registration form";
$lang['section_instructions'] =					"instructions";
$lang['section_reg_complete'] = 				"your registration is complete";
$lang['section_preview'] =						"preview";
$lang['hdr_invite_notes'] = 					"customise the email";


//SUBMIT BUTTONS
$lang['sub_register'] = 						"register";
$lang['sub_edit_again'] = 						"edit again";
$lang['sub_preview'] = 							"preview";



//EMAIL MESSAGE SUBJECTS
$lang['subject_welcome_br'] = 					"Welcome to aroundme";


//TEXTS
$lang['txt_dob'] = 								"date of birth";
$lang['txt_email'] = 							"email";
$lang['txt_hometown'] = 						"place of residence";
$lang['txt_firstname'] = 						"firstname";
$lang['txt_female'] = 							"female";
$lang['txt_gender'] = 							"gender";
$lang['txt_none'] = 							"undisclosed";
$lang['txt_lang'] = 							"preferred language";
$lang['txt_instructions'] =						"Fill out the registration form. Once you've finished press the 'register' button.<br /><p>The new member will be sent an invitation email.<br /></p><p>Remember to put the correct date of birth or to remind them to change it once registered as they will need it should they forget their password.<br /></p>";
$lang['txt_invited_personal'] =					"Join my friends in this community!";
$lang['txt_male'] = 							"male";
$lang['txt_nickname'] = 						"nickname";
$lang['txt_surname'] = 							"surname";
$lang['txt_welcome'] = 							"Fill in the form to register a new membership";
$lang['txt_index_intro_post_reg'] = 			"Registration is complete.";
$lang['txt_instructions2'] =					"The invited member will receive an email from you with a link in it. They need to press the link to complete registration.<br />";
$lang['txt_lang_selection'] = 					"languages I can read";
$lang['txt_preview'] = 							"check your information and if correct press 'register'";
$lang['txt_default_profile_name'] = 			"default";
$lang['txt_default_profile_hometown'] = 		"Stockholm";
$lang['txt_subject'] =							"subject";
$lang['txt_invite'] =							"You have been invited into Aroundme!";
$lang['txt_message'] =							"message";
$lang['txt_invite_message_txt'] =				"Join me in Aroundme!";

?>

==> aroundme_0_6_2.tar.tgz: aroundme_0_6_2/aroundme/language/1/barnraiser_01/node_register_user.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'common.lang.php');


//HEADERS
$lang['hdr_invite'] = 						"you've been invited";
$lang['hdr_registration'] = 				"registration form";
$lang['hdr_instructions'] =					"instructions";
$lang['hdr_reg_complete'] = 				"your registration is complete";
$lang['hdr_preview'] =						"preview";
$lang['hdr_invite_notes'] = 					"customise the email";


//SUBMIT BUTTONS
$lang['sub_register'] = 						"register";
$lang['sub_edit_again'] = 						"edit again";
$lang['sub_preview'] = 							"preview";


//EMAIL MESSAGE SUBJECTS
$lang['subject_welcome_br'] = 					"Welcome to AROUNDMe";


//TEXTS
$lang['txt_firstname'] = 						"firstname";
$lang['txt_dob'] = 								"date of birth";
$lang['txt_email'] = 							"email";
$lang['txt_lang'] = 							"preferred language";
$lang['txt_instructions'] =						"Fill out the registration form. Once you've finished press the 'register' button.<br /><p>The new member will be sent an invitation email.<br /></p><p>Remember to put the correct date of birth or to remind them to change it once registered as they will need it should they forget their password.<br /></p>";
$lang['txt_invited_personal'] =					"Join my network!";
$lang['txt_welcome'] = 							"Fill in the form to register a new membership";
$lang['txt_index_intro_post_reg'] = 			"Registration is complete.";
$lang['txt_instructions2'] =					"The invited member will receive an email from you with a link in it. They need to press the link to complete registration.<br />";
$lang['txt_lang_selection'] = 					"languages they can read";
$lang['txt_preview'] = 							"check your information and if correct press 'register'";
$lang['txt_default_profile_name'] = 			"default";
$lang['txt_default_profile_hometown'] = 		"Stockholm";
$lang['txt_subject'] =							"subject";
$lang['txt_invite'] =							"You have been invited into AROUNDMe!";
$lang['txt_message'] =							"message";
$lang['txt_invite_message_txt'] =				"Join me in AROUNDMe!";

?>
